@@ -141,7 +141,7 @@ class Cling(object):
 
     def _file_like(self, full_path):
         """Return the appropriate file object."""
-        return open(full_path)
+        return open(full_path, 'rb')
 
     def _body(self, full_path, environ, file_like):
         """Return an iterator over the body of the response."""
@@ -245,7 +245,7 @@ class Shock(Cling):
         if magic is not None:
             return magic.file_like(full_path)
         else:
-            return open(full_path)
+            return open(full_path, 'rb')
 
     def _body(self, full_path, environ, file_like):
         """Return an iterator over the body of the response."""
@@ -298,7 +298,7 @@ class BaseMagic(object):
 
     def file_like(self, full_path):
         """Return a file object for path."""
-        return open(full_path)
+        return open(full_path, 'rb')
 
     def body(self, environ, file_like):
         """Return an iterator over the body of the response."""
